@@ -12,12 +12,12 @@
 #' @examples
 #' sample_gnp_signed(10, 0.4, 0.5)
 sample_gnp_signed <- function(n, p, p_neg, directed = FALSE, loops = FALSE) {
-  g <- igraph::sample_gnp(n = n, p = p, directed = directed, loops = loops)
-  if (missing(p_neg)) {
-    stop("p_neg missing with no default")
-  }
-  igraph::E(g)$sign <- sample(c(-1, 1), igraph::ecount(g), replace = TRUE, prob = c(p_neg, 1 - p_neg))
-  g
+    g <- igraph::sample_gnp(n = n, p = p, directed = directed, loops = loops)
+    if (missing(p_neg)) {
+        stop("p_neg missing with no default")
+    }
+    igraph::E(g)$sign <- sample(c(-1, 1), igraph::ecount(g), replace = TRUE, prob = c(p_neg, 1 - p_neg))
+    g
 }
 
 #' Bipartite random signed graphs
@@ -33,14 +33,14 @@ sample_gnp_signed <- function(n, p, p_neg, directed = FALSE, loops = FALSE) {
 #' @export
 #'
 #' @examples
-#' sample_bipartite_signed(10,10,0.5,0.5)
-sample_bipartite_signed <- function(n1, n2, p, p_neg, directed = FALSE, mode = c("out", "in", "all")){
-  g <- igraph::sample_bipartite(n1 = n1, n2 = n2, p = p, directed = directed, mode = mode)
-  if (missing(p_neg)) {
-    stop("p_neg missing with no default")
-  }
-  igraph::E(g)$sign <- sample(c(-1, 1), igraph::ecount(g), replace = TRUE, prob = c(p_neg, 1 - p_neg))
-  g
+#' sample_bipartite_signed(10, 10, 0.5, 0.5)
+sample_bipartite_signed <- function(n1, n2, p, p_neg, directed = FALSE, mode = c("out", "in", "all")) {
+    g <- igraph::sample_bipartite(n1 = n1, n2 = n2, p = p, directed = directed, mode = mode)
+    if (missing(p_neg)) {
+        stop("p_neg missing with no default")
+    }
+    igraph::E(g)$sign <- sample(c(-1, 1), igraph::ecount(g), replace = TRUE, prob = c(p_neg, 1 - p_neg))
+    g
 }
 
 
@@ -58,38 +58,38 @@ sample_bipartite_signed <- function(n1, n2, p, p_neg, directed = FALSE, mode = c
 #' sample_islands_signed(3, 10, 0.5, 1)
 #' @export
 sample_islands_signed <- function(islands.n, islands.size, islands.pin, n.inter) {
-  if (islands.n <= 1) {
-    stop("islands.n should be greater than one")
-  }
-  if (islands.size <= 1) {
-    stop("islands.size should be greater than one")
-  }
-  if (islands.pin < 0 | islands.pin > 1) {
-    stop("islands.pin should be between zero and one")
-  }
-  if (n.inter <= 0) {
-    stop("n.inter should be greater than zero")
-  }
-  el <- matrix(0, 0, 2)
-  for (i in 1:islands.n) {
-    tmp <- t(utils::combn(((i - 1) * islands.size + 1):(i * islands.size), 2))
-    tmp <- tmp[sample(c(FALSE, TRUE), nrow(tmp), replace = TRUE, prob = c(1 - islands.pin, islands.pin)), ]
-    el <- rbind(el, tmp)
-  }
-  el <- cbind(el, 1)
-  for (i in 1:islands.n) {
-    outside <- setdiff(1:(islands.size * islands.n), ((i - 1) * islands.size + 1):(i * islands.size))
-    inside <- ((i - 1) * islands.size + 1):(i * islands.size)
-    to <- sample(outside, n.inter, replace = TRUE)
-    from <- sample(inside, n.inter, replace = TRUE)
-    tmp <- cbind(from, to, -1)
-    el <- rbind(el, tmp)
-  }
-  g <- igraph::graph_from_edgelist(el[, 1:2], directed = FALSE)
-  igraph::E(g)$sign <- el[, 3]
-  igraph::V(g)$grp <- as.character(rep(1:islands.n, each = islands.size))
-  g <- igraph::delete.edges(g, which(igraph::is.multiple(g)))
-  g
+    if (islands.n <= 1) {
+        stop("islands.n should be greater than one")
+    }
+    if (islands.size <= 1) {
+        stop("islands.size should be greater than one")
+    }
+    if (islands.pin < 0 || islands.pin > 1) {
+        stop("islands.pin should be between zero and one")
+    }
+    if (n.inter <= 0) {
+        stop("n.inter should be greater than zero")
+    }
+    el <- matrix(0, 0, 2)
+    for (i in 1:islands.n) {
+        tmp <- t(utils::combn(((i - 1) * islands.size + 1):(i * islands.size), 2))
+        tmp <- tmp[sample(c(FALSE, TRUE), nrow(tmp), replace = TRUE, prob = c(1 - islands.pin, islands.pin)), ]
+        el <- rbind(el, tmp)
+    }
+    el <- cbind(el, 1)
+    for (i in 1:islands.n) {
+        outside <- setdiff(1:(islands.size * islands.n), ((i - 1) * islands.size + 1):(i * islands.size))
+        inside <- ((i - 1) * islands.size + 1):(i * islands.size)
+        to <- sample(outside, n.inter, replace = TRUE)
+        from <- sample(inside, n.inter, replace = TRUE)
+        tmp <- cbind(from, to, -1)
+        el <- rbind(el, tmp)
+    }
+    g <- igraph::graph_from_edgelist(el[, 1:2], directed = FALSE)
+    igraph::E(g)$sign <- el[, 3]
+    igraph::V(g)$grp <- as.character(rep(1:islands.n, each = islands.size))
+    g <- igraph::delete.edges(g, which(igraph::is.multiple(g)))
+    g
 }
 
 #' @title circular signed graph
@@ -107,40 +107,40 @@ sample_islands_signed <- function(islands.n, islands.size, islands.pin, n.inter)
 #' @export
 #
 graph_circular_signed <- function(n, r = 1, pos = 0.1, neg = 0.1) {
-  if (missing(n)) {
-    stop('argument "n" is missing, with no default')
-  }
-  pts <- circleFun(r = r, npoints = n)
+    if (missing(n)) {
+        stop('argument "n" is missing, with no default')
+    }
+    pts <- circleFun(r = r, npoints = n)
 
-  D <- arcDistMat(as.matrix(pts), r)
+    D <- arcDistMat(as.matrix(pts), r)
 
-  thr <- (2 * pi * r) * pos
-  anti <- arc_dist(c(0, r), c(0, -r), r) * (1 - neg)
-  P <- (D <= thr & D != 0) + 0
-  N <- (D >= anti & D != 0) + 0
+    thr <- (2 * pi * r) * pos
+    anti <- arc_dist(c(0, r), c(0, -r), r) * (1 - neg)
+    P <- (D <= thr & D != 0) + 0
+    N <- (D >= anti & D != 0) + 0
 
-  A <- P - N
-  g <- igraph::graph_from_adjacency_matrix(A, mode = "undirected", weighted = TRUE)
-  igraph::E(g)$sign <- ifelse(igraph::E(g)$weight == 1, 1, -1)
-  g <- igraph::delete_edge_attr(g, "weight")
-  igraph::V(g)$x <- pts$x
-  igraph::V(g)$y <- pts$y
-  g
+    A <- P - N
+    g <- igraph::graph_from_adjacency_matrix(A, mode = "undirected", weighted = TRUE)
+    igraph::E(g)$sign <- ifelse(igraph::E(g)$weight == 1, 1, -1)
+    g <- igraph::delete_edge_attr(g, "weight")
+    igraph::V(g)$x <- pts$x
+    igraph::V(g)$y <- pts$y
+    g
 }
 
 # create points on a circle with radius r around center
 circleFun <- function(center = c(0, 0), r = 1, npoints = 20) {
-  pts_seq <- seq(0, 2 * pi, length.out = npoints * 100)
-  pts_samp <- sample(pts_seq, npoints)
+    pts_seq <- seq(0, 2 * pi, length.out = npoints * 100)
+    pts_samp <- sample(pts_seq, npoints)
 
-  xx <- center[1] + r * cos(pts_samp)
-  yy <- center[2] + r * sin(pts_samp)
-  return(data.frame(x = xx, y = yy))
+    xx <- center[1] + r * cos(pts_samp)
+    yy <- center[2] + r * sin(pts_samp)
+    return(data.frame(x = xx, y = yy))
 }
 
 # distance between two points x and y on a circle with radius r
 arc_dist <- function(x, y, r) {
-  c <- sqrt((x[1] - y[1])^2 + (x[2] - y[2])^2)
-  theta <- acos((2 * r^2 - c^2) / (2 * r^2))
-  2 * pi * r * theta / (2 * pi)
+    c <- sqrt((x[1] - y[1])^2 + (x[2] - y[2])^2)
+    theta <- acos((2 * r^2 - c^2) / (2 * r^2))
+    2 * pi * r * theta / (2 * pi)
 }
